import _typeof from "@babel/runtime/helpers/typeof";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useState } from "react";
import { layoutSettings, navigatorSettings } from "./config";
import { fetchGraphQLDataJSON } from "../../../util/fetch";
import { formatData } from "./formatter";
import { parseData } from "../../../util/parser";
import './style.css';
import cytoscape from 'cytoscape';
import euler from 'cytoscape-euler';
import popper from 'cytoscape-popper';
import dagre from 'cytoscape-dagre';
import "cytoscape-navigator/cytoscape.js-navigator.css";
import { mapConfig } from "./config-mapper";
import useDimensions from "react-cool-dimensions";
import { LAYOUT_NAMES } from "./config";

var navigator = require('cytoscape-navigator');

export var CytoScapeRenderer = function CytoScapeRenderer(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === void 0 ? undefined : _ref$data,
      _ref$layout = _ref.layout,
      layout = _ref$layout === void 0 ? 'graph' : _ref$layout,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style,
      _ref$schema = _ref.schema,
      schema = _ref$schema === void 0 ? {} : _ref$schema,
      _ref$interactions = _ref.interactions,
      interactions = _ref$interactions === void 0 ? {} : _ref$interactions,
      _ref$showNavigator = _ref.showNavigator,
      showNavigator = _ref$showNavigator === void 0 ? false : _ref$showNavigator,
      graphqlUrl = _ref.graphqlUrl,
      graphqlQuery = _ref.graphqlQuery;

  var _useState = useState(undefined),
      _useState2 = _slicedToArray(_useState, 2),
      ref = _useState2[0],
      setRef = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      dataLoaded = _useState4[0],
      setDataLoaded = _useState4[1];

  var _useDimensions = useDimensions({
    onResize: function onResize(_ref2) {
      var observe = _ref2.observe,
          unobserve = _ref2.unobserve,
          width = _ref2.width,
          height = _ref2.height,
          entry = _ref2.entry;
      // Triggered whenever the size of the target is changed...
      unobserve(); // To stop observing the current target element

      // To stop observing the current target element
      observe(); // To re-start observing the current target element
    }
  }),
      observe = _useDimensions.observe,
      unobserve = _useDimensions.unobserve,
      width = _useDimensions.width,
      height = _useDimensions.height,
      entry = _useDimensions.entry;

  if (ref) {
    var cy = cytoscape({
      container: ref,
      style: getStyle(style)
    });
    cytoscape.use(euler);
    cytoscape.use(dagre);
    cytoscape.use(popper);

    if (data === undefined && graphqlQuery !== undefined && graphqlUrl !== undefined) {
      fetchGraphQLDataJSON(graphqlUrl, graphqlQuery).then(function (_data) {
        setDataLoaded(true);
        var parsedData = parseData(_data, schema);
        var formattedData = formatData(parsedData);
        var eles = cy.add(formattedData);
        cy.layout(_objectSpread(_objectSpread({}, layoutSettings), {}, {
          name: LAYOUT_NAMES[layout]
        })).run();
        cy.filter('node').forEach(function (t) {
          bindPopper(t);
        });
      });
    } else {
      if (dataLoaded == false) {
        setDataLoaded(true);
      }

      var parsedData = parseData(data, schema);
      var formattedData = formatData(parsedData);
      var eles = cy.add(formattedData);
      cy.layout(_objectSpread(_objectSpread({}, layoutSettings), {}, {
        name: LAYOUT_NAMES[layout]
      })).run();
      cy.filter('node').forEach(function (t) {
        bindPopper(t);
      });
    }
    /**
     * Handles rendering the navigator window on the bottom right of the screen.
     */


    if (showNavigator) {
      cytoscape.use(navigator);
      var nav = cy.navigator(navigatorSettings); // get navigator instance, nav
    } else {
      var div = document.getElementById("navigator");

      if (div) {
        div.innerHTML = '';
      }
    } //


    cy.on("click", "node", function (e) {
      return interactions && interactions.onNodeClick && interactions.onNodeClick(e.target._private.data);
    });
    cy.on("cxttap", "node", function (e) {
      return interactions && interactions.onNodeRightClick && interactions.onNodeRightClick(e.target._private.data);
    });
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    style: {
      width: 300,
      height: 200,
      position: 'absolute',
      right: 0,
      bottom: 0,
      overflow: 'hidden'
    },
    id: "navigator"
  }, " "), !dataLoaded ? /*#__PURE__*/React.createElement("div", null, "Loading...") : /*#__PURE__*/React.createElement(React.Fragment, null), /*#__PURE__*/React.createElement("div", {
    id: "cy",
    ref: function ref(cyRef) {
      setRef(cyRef);
    },
    style: {
      width: "100%",
      height: "100%"
    }
  }, " "));
};

function getStyle(config) {
  return mapConfig(config);
}
/**
 *
 * @param target node or edge
 */


function bindPopper(target) {
  var tooltipId = "popper-target-".concat(target.id());
  var existingTarget = document.getElementById(tooltipId);

  if (existingTarget && existingTarget.length !== 0) {
    existingTarget.remove();
  }

  var popper = target.popper({
    content: function content() {
      // create div container
      var tooltip = document.createElement('div'); // adding id for easier JavaScript control

      tooltip.id = tooltipId; // adding class for easier CSS control

      tooltip.classList.add('target-popper'); // create actual table

      var table = document.createElement('table'); // append table to div container

      tooltip.append(table);
      var targetData = target.data(); // loop through target data

      for (var prop in targetData) {
        if (prop == "id") continue;
        if (!targetData.hasOwnProperty(prop)) continue;
        var targetValue = targetData[prop]; // no recursive or reduce support

        if (_typeof(targetValue) === "object") continue;
        var tr = table.insertRow();
        var tdTitle = tr.insertCell();
        var tdValue = tr.insertCell();
        tdTitle.innerText = prop;
        tdValue.innerText = targetValue;
      }

      document.body.appendChild(tooltip);
      return tooltip;
    }
  });
  target.on('position', function () {
    popper.update();
  });
  target.cy().on('pan zoom resize', function () {
    popper.update();
  });
  target.on('mouseover', function () {
    if (document.getElementById(tooltipId)) {
      document.getElementById(tooltipId).classList.add('active');
    }
  }).on('mouseout', function () {
    if (document.getElementById(tooltipId)) {
      document.getElementById(tooltipId).classList.remove('active');
    }
  });
}