import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import React, { useRef } from "react";
import { ForceGraph2D } from "react-force-graph";
import { fetchGraphQLDataJSON } from "../../../util/fetch";
import { formatData } from "./formatter";
import { parseData } from "../../../util/parser";
import ReactDOMServer from 'react-dom/server';
import useDimensions from "react-cool-dimensions";
import { mapConfig } from "./config-mapper";
import './style.css';
import { LAYOUT_NAMES } from "./config";

var generateTooltip = function generateTooltip(value) {
  var tooltip = /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("table", null, Object.keys(value).map(function (key) {
    if (key !== "id" && key !== "color" && key !== "size" && key !== "index" && key !== "__indexColor" && key !== "x" && key !== "y" && key !== "vx" && key !== "vy" && key !== "fx" && key !== "fy") {
      return /*#__PURE__*/React.createElement("tr", null, /*#__PURE__*/React.createElement("td", {
        style: {
          paddingRight: "10px"
        }
      }, /*#__PURE__*/React.createElement("b", null, key)), /*#__PURE__*/React.createElement("td", null, value[key]));
    }
  })));
  return ReactDOMServer.renderToString(tooltip);
};

export var ReactForceGraphRenderer = function ReactForceGraphRenderer(_ref) {
  var _ref$data = _ref.data,
      data = _ref$data === void 0 ? undefined : _ref$data,
      _ref$layout = _ref.layout,
      layout = _ref$layout === void 0 ? 'graph' : _ref$layout,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style,
      _ref$schema = _ref.schema,
      schema = _ref$schema === void 0 ? {} : _ref$schema,
      _ref$interactions = _ref.interactions,
      interactions = _ref$interactions === void 0 ? {} : _ref$interactions,
      _ref$showNavigator = _ref.showNavigator,
      showNavigator = _ref$showNavigator === void 0 ? false : _ref$showNavigator,
      graphqlUrl = _ref.graphqlUrl,
      graphqlQuery = _ref.graphqlQuery;

  var _React$useState = React.useState(undefined),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      vizData = _React$useState2[0],
      setVizData = _React$useState2[1];

  var _React$useState3 = React.useState(true),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      firstRun = _React$useState4[0],
      setFirstRun = _React$useState4[1];

  var _useDimensions = useDimensions({
    onResize: function onResize(_ref2) {
      var observe = _ref2.observe,
          unobserve = _ref2.unobserve,
          width = _ref2.width,
          height = _ref2.height,
          entry = _ref2.entry;
      // Triggered whenever the size of the target is changed...
      unobserve(); // To stop observing the current target element

      // To stop observing the current target element
      observe(); // To re-start observing the current target element
    }
  }),
      observe = _useDimensions.observe,
      unobserve = _useDimensions.unobserve,
      width = _useDimensions.width,
      height = _useDimensions.height,
      entry = _useDimensions.entry; // parse visualization data if it is not yet set.


  if (vizData === undefined) {
    if (data === undefined && graphqlQuery !== undefined && graphqlUrl !== undefined) {
      fetchGraphQLDataJSON(graphqlUrl, graphqlQuery).then(function (_data) {
        var parsedData = parseData(_data, schema);
        var formattedData = formatData(parsedData);
        var mappedData = mapConfig(style, formattedData);
        setVizData(mappedData);
      });
    } else {
      var parsedData = parseData(data, schema);
      var formattedData = formatData(parsedData);
      var mappedData = mapConfig(style, formattedData);
      setVizData(mappedData);
    }
  }

  var fgRef = useRef();
  var visualization = /*#__PURE__*/React.createElement(ForceGraph2D, {
    ref: fgRef,
    width: width,
    height: height,
    cooldownTicks: 50,
    nodeLabel: function nodeLabel(node) {
      return "<div>".concat(generateTooltip(node), "</div>");
    },
    linkWidth: 3,
    dagMode: LAYOUT_NAMES[layout],
    nodeVal: function nodeVal(node) {
      return node.size;
    },
    onNodeClick: function onNodeClick(e) {
      return interactions && interactions.onNodeClick && interactions.onNodeClick(e);
    },
    onNodeRightClick: function onNodeRightClick(e) {
      return interactions && interactions.onNodeRightClick && interactions.onNodeRightClick(e);
    },
    nodeCanvasObjectMode: function nodeCanvasObjectMode() {
      return "after";
    },
    onEngineStop: function onEngineStop() {
      if (firstRun) {
        fgRef.current.zoomToFit(200);
        setFirstRun(false);
      }
    },
    nodeCanvasObject: function nodeCanvasObject(node, ctx, globalScale) {
      var label = "";

      if (node.name) {
        label = node.name;
      } else if (node.title) {
        label = node.title;
      }

      var fontSize = 10;
      ctx.font = "".concat(fontSize, "px Sans-Serif");
      ctx.fillStyle = "black";
      ctx.textAlign = "center";
      ctx.fillText(label, node.x, node.y + 1);
    },
    graphData: vizData ? vizData : {
      nodes: [],
      links: []
    }
  });
  return /*#__PURE__*/React.createElement("div", {
    style: {
      width: "100%",
      height: "100%"
    },
    ref: observe
  }, vizData ? visualization : "Loading...");
};