import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import _createClass from "@babel/runtime/helpers/createClass";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _typeof from "@babel/runtime/helpers/typeof";
import { v4 as uuidv4 } from 'uuid';

var isObj = function isObj(obj) {
  return _typeof(obj) === 'object';
};

export var GraphNode = /*#__PURE__*/_createClass(function GraphNode() {
  _classCallCheck(this, GraphNode);

  _defineProperty(this, "id", "");

  _defineProperty(this, "label", "Node");

  _defineProperty(this, "properties", {});
});
export var GraphEdge = /*#__PURE__*/_createClass(function GraphEdge(id, source, target) {
  _classCallCheck(this, GraphEdge);

  _defineProperty(this, "id", "");

  _defineProperty(this, "source", "");

  _defineProperty(this, "target", "");

  _defineProperty(this, "type", "Edge");

  _defineProperty(this, "properties", {});

  this.id = id;
  this.source = source;
  this.target = target;
});
var nodes;
var edges;

function parseNodesFromDict(dict, schema) {
  // Return node
  var node = new GraphNode();
  var _properties = {};
  var labelField = schema && schema["nodeLabelField"] ? schema["nodeLabelField"] : "__typename";

  if (labelField in dict && dict[labelField] != null) {
    node.label = dict[labelField];
  }

  var idField = schema && schema["nodeIdField"] && schema["nodeIdField"][node.label] ? schema["nodeIdField"][node.label] : "ID";

  if (idField in dict && dict[idField] != null) {
    node.id = dict[idField];
  } else {
    node.id = JSON.stringify(dict);
  }

  for (var _i = 0, _Object$entries = Object.entries(dict); _i < _Object$entries.length; _i++) {
    var _Object$entries$_i = _slicedToArray(_Object$entries[_i], 2),
        _key = _Object$entries$_i[0],
        _value = _Object$entries$_i[1];

    if (_value != null) {
      // Nested object or list of objects = relationship traversal
      if (Array.isArray(_value) && _value.every(isObj)) {
        _value.forEach(function (nestedObject) {
          // Parse node (recursively)
          var _node = parseNodesFromDict(nestedObject, schema); // Add relationship, with source and target id


          edges.push(new GraphEdge(uuidv4(), node.id, _node.id));
        });
      } else if (_typeof(_value) === 'object' && !Array.isArray(_value)) {
        // TODO = Exclude non-nested objects like date/datetime
        // Parse node and add it to nodes
        var _node = parseNodesFromDict(_value, schema); // Add relationship, with source and target id


        edges.push(new GraphEdge(uuidv4(), node.id, _node.id));
      } // Node property
      else {
        if (_key != labelField) {
          _properties[_key] = _value;
        }
      }
    }
  }

  node.properties = _properties;
  nodes.push(node);
  return node;
}

export function parseData(data, schema) {
  nodes = Array();
  edges = Array(); // Iterate first level - These are nodes

  for (var _i2 = 0, _Object$entries2 = Object.entries(data["data"]); _i2 < _Object$entries2.length; _i2++) {
    var _Object$entries2$_i = _slicedToArray(_Object$entries2[_i2], 2),
        key = _Object$entries2$_i[0],
        value = _Object$entries2$_i[1];

    // Iterate over the top-level nodes
    // @ts-ignore
    value.forEach(function (dict) {
      parseNodesFromDict(dict, schema);
    });
  }

  return [nodes, edges];
}