"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.TreeLayout = exports.SimpleData = exports.RuleBasedStyling = exports.LiveGraphQLData = exports.Interactions = exports.CustomSchema = exports.BasicStyling = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _defaults = require("./defaults");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var SAMPLE_DATA = {
  "data": {
    "actors": [{
      "__typename": "Actor",
      "ID": 1,
      "name": "François Lallement",
      "acted_in": [{
        "__typename": "Movie",
        "ID": 3,
        "title": "Trip to the Moon, A (Voyage dans la lune, Le)",
        "genres": [{
          "__typename": "Genre",
          "ID": 5,
          "name": "Action"
        }, {
          "__typename": "Genre",
          "ID": 6,
          "name": "Adventure"
        }]
      }]
    }, {
      "__typename": "Actor",
      "ID": 2,
      "name": "Jules-Eugène Legris",
      "acted_in": [{
        "__typename": "Movie",
        "ID": 3,
        "title": "Trip to the Moon, A (Voyage dans la lune, Le)",
        "genres": [{
          "__typename": "Genre",
          "ID": 7,
          "name": "Sci-Fi"
        }]
      }]
    }]
  }
};
var SAMPLE_DATA_CUSTOM_LABELS = {
  "data": {
    "movies": [{
      "mylabel": "Movie",
      "title": "Toy Story",
      "released": "1995-11-22",
      "genres": [{
        "mylabel": "Genre",
        "name": "Adventure"
      }]
    }, {
      "mylabel": "Movie",
      "title": "Jumanji",
      "released": "1995-12-15",
      "genres": [{
        "mylabel": "Genre",
        "name": "Adventure"
      }]
    }, {
      "mylabel": "Movie",
      "title": "Grumpier Old Men",
      "released": "1995-12-22",
      "genres": [{
        "mylabel": "Genre",
        "name": "Comedy"
      }]
    }, {
      "mylabel": "Movie",
      "title": "Waiting to Exhale",
      "released": "1995-12-22",
      "genres": [{
        "mylabel": "Genre",
        "name": "Romance"
      }]
    }, {
      "mylabel": "Movie",
      "title": "Father of the Bride Part II",
      "released": "1995-12-08",
      "genres": [{
        "mylabel": "Genre",
        "name": "Comedy"
      }]
    }]
  }
};
var GRAPHQL_URL = "https://movies.neo4j-graphql.com/";
var GRAPHQL_QUERY = "{\n   actors(options: {limit: 20}) {\n     __typename\n     name\n     acted_in {\n       __typename\n       title\n       released\n       genres {\n         __typename\n         name\n       }\n     }\n   }\n}";
var GRAPHQL_QUERY_TREE = "{\n   actors(options: {limit: 1}) {\n     __typename\n     name\n     acted_in {\n       __typename\n       title\n       released\n       genres {\n         __typename\n         name\n       }\n     }\n   }\n}";

var _default = _objectSpread({
  title: 'Examples'
}, _defaults.defaultConfig);

exports["default"] = _default;

var SimpleData = _defaults.Template.bind({});

exports.SimpleData = SimpleData;
SimpleData.args = _objectSpread(_objectSpread({}, _defaults.defaultArgs), {}, {
  data: SAMPLE_DATA
});

var LiveGraphQLData = _defaults.Template.bind({});

exports.LiveGraphQLData = LiveGraphQLData;
LiveGraphQLData.args = _objectSpread(_objectSpread({}, _defaults.defaultArgs), {}, {
  showNavigator: false,
  renderer: "react-force-graph",
  graphqlUrl: GRAPHQL_URL,
  graphqlQuery: GRAPHQL_QUERY
});

var BasicStyling = _defaults.Template.bind({});

exports.BasicStyling = BasicStyling;
BasicStyling.args = _objectSpread(_objectSpread({}, _defaults.defaultArgs), {}, {
  style: {
    nodeCaption: {
      Movie: "title",
      Actor: "name",
      Genre: "name"
    },
    nodeColor: {
      Movie: "red",
      Actor: "blue",
      Genre: "green"
    },
    nodeSize: {
      Movie: 40,
      Actor: 20,
      Genre: 30
    },
    nodeCaptionSize: {
      Movie: 15,
      Actor: 15,
      Genre: 15
    }
  },
  showNavigator: true,
  graphqlUrl: GRAPHQL_URL,
  graphqlQuery: GRAPHQL_QUERY
});

var RuleBasedStyling = _defaults.Template.bind({});

exports.RuleBasedStyling = RuleBasedStyling;
RuleBasedStyling.args = _objectSpread(_objectSpread({}, _defaults.defaultArgs), {}, {
  style: {
    nodeCaption: {
      Movie: "title",
      Actor: "name",
      Genre: "name"
    },
    nodeColor: {
      Movie: "green",
      Actor: "orange",
      Genre: "blue"
    },
    nodeSize: {
      Movie: function Movie(movie) {
        if (movie.released) {
          return movie.released.split('-')[0] - 1900;
        } else {
          return 40;
        }
      },
      Actor: 15,
      Genre: 15
    }
  },
  showNavigator: false,
  graphqlUrl: GRAPHQL_URL,
  renderer: "react-force-graph",
  graphqlQuery: GRAPHQL_QUERY
});

var TreeLayout = _defaults.Template.bind({});

exports.TreeLayout = TreeLayout;
TreeLayout.args = _objectSpread(_objectSpread({}, _defaults.defaultArgs), {}, {
  showNavigator: false,
  layout: "tree",
  style: {
    nodeColor: {
      Movie: "green"
    },
    nodeCaptionSize: {
      Movie: 10
    }
  },
  schema: {
    nodeLabelField: "__typename",
    nodeIdField: {
      Movie: "title"
    }
  },
  graphqlUrl: GRAPHQL_URL,
  graphqlQuery: GRAPHQL_QUERY_TREE
});

var Interactions = _defaults.Template.bind({});

exports.Interactions = Interactions;
Interactions.args = _objectSpread(_objectSpread({}, _defaults.defaultArgs), {}, {
  interactions: {
    onNodeClick: function onNodeClick(e) {
      return alert(e.name ? e.name : e.title);
    },
    onNodeRightClick: function onNodeRightClick(e) {
      return alert('right click');
    }
  },
  showNavigator: false,
  graphqlUrl: GRAPHQL_URL,
  graphqlQuery: GRAPHQL_QUERY
});

var CustomSchema = _defaults.Template.bind({});

exports.CustomSchema = CustomSchema;
CustomSchema.args = _objectSpread(_objectSpread({}, _defaults.defaultArgs), {}, {
  schema: {
    nodeLabelField: "mylabel",
    nodeIdField: {
      Movie: "title",
      Genre: "name"
    }
  },
  style: {
    nodeColor: {
      Movie: "orange",
      Genre: function Genre(genre) {
        return genre.name == "Adventure" ? "green" : "purple";
      }
    }
  },
  showNavigator: false,
  data: SAMPLE_DATA_CUSTOM_LABELS
});