"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GraphNode = exports.GraphEdge = void 0;
exports.parseData = parseData;

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _createClass2 = _interopRequireDefault(require("@babel/runtime/helpers/createClass"));

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _typeof2 = _interopRequireDefault(require("@babel/runtime/helpers/typeof"));

var _uuid = require("uuid");

var isObj = function isObj(obj) {
  return (0, _typeof2["default"])(obj) === 'object';
};

var GraphNode = /*#__PURE__*/(0, _createClass2["default"])(function GraphNode() {
  (0, _classCallCheck2["default"])(this, GraphNode);
  (0, _defineProperty2["default"])(this, "id", "");
  (0, _defineProperty2["default"])(this, "label", "Node");
  (0, _defineProperty2["default"])(this, "properties", {});
});
exports.GraphNode = GraphNode;
var GraphEdge = /*#__PURE__*/(0, _createClass2["default"])(function GraphEdge(id, source, target) {
  (0, _classCallCheck2["default"])(this, GraphEdge);
  (0, _defineProperty2["default"])(this, "id", "");
  (0, _defineProperty2["default"])(this, "source", "");
  (0, _defineProperty2["default"])(this, "target", "");
  (0, _defineProperty2["default"])(this, "type", "Edge");
  (0, _defineProperty2["default"])(this, "properties", {});
  this.id = id;
  this.source = source;
  this.target = target;
});
exports.GraphEdge = GraphEdge;
var nodes;
var edges;

function parseNodesFromDict(dict, schema) {
  // Return node
  var node = new GraphNode();
  var _properties = {};
  var labelField = schema && schema["nodeLabelField"] ? schema["nodeLabelField"] : "__typename";

  if (labelField in dict && dict[labelField] != null) {
    node.label = dict[labelField];
  }

  var idField = schema && schema["nodeIdField"] && schema["nodeIdField"][node.label] ? schema["nodeIdField"][node.label] : "ID";

  if (idField in dict && dict[idField] != null) {
    node.id = dict[idField];
  } else {
    node.id = JSON.stringify(dict);
  }

  for (var _i = 0, _Object$entries = Object.entries(dict); _i < _Object$entries.length; _i++) {
    var _Object$entries$_i = (0, _slicedToArray2["default"])(_Object$entries[_i], 2),
        _key = _Object$entries$_i[0],
        _value = _Object$entries$_i[1];

    if (_value != null) {
      // Nested object or list of objects = relationship traversal
      if (Array.isArray(_value) && _value.every(isObj)) {
        _value.forEach(function (nestedObject) {
          // Parse node (recursively)
          var _node = parseNodesFromDict(nestedObject, schema); // Add relationship, with source and target id


          edges.push(new GraphEdge((0, _uuid.v4)(), node.id, _node.id));
        });
      } else if ((0, _typeof2["default"])(_value) === 'object' && !Array.isArray(_value)) {
        // TODO = Exclude non-nested objects like date/datetime
        // Parse node and add it to nodes
        var _node = parseNodesFromDict(_value, schema); // Add relationship, with source and target id


        edges.push(new GraphEdge((0, _uuid.v4)(), node.id, _node.id));
      } // Node property
      else {
        if (_key != labelField) {
          _properties[_key] = _value;
        }
      }
    }
  }

  node.properties = _properties;
  nodes.push(node);
  return node;
}

function parseData(data, schema) {
  nodes = Array();
  edges = Array(); // Iterate first level - These are nodes

  for (var _i2 = 0, _Object$entries2 = Object.entries(data["data"]); _i2 < _Object$entries2.length; _i2++) {
    var _Object$entries2$_i = (0, _slicedToArray2["default"])(_Object$entries2[_i2], 2),
        key = _Object$entries2$_i[0],
        value = _Object$entries2$_i[1];

    // Iterate over the top-level nodes
    // @ts-ignore
    value.forEach(function (dict) {
      parseNodesFromDict(dict, schema);
    });
  }

  return [nodes, edges];
}